# TES02 - Unit Testing

Best practices cho unit testing.

## Best Practices

| # | Best Practice | Mô tả |
|---|---------------|-------|
| BP01 | [Unit Test Best Practices](TES02-BP01-Unit-Test-Best-Practices.md) | Writing good unit tests |
| BP02 | [Mocking Strategies](TES02-BP02-Mocking-Strategies.md) | How to mock dependencies |

## Tham khảo

- Jest Documentation
- Testing Library Guiding Principles
- Unit Testing Principles by Vladimir Khorikov
